import { Nullable } from '@salesforce/ts-types';
interface PackageConfig {
    path: string;
    name: string;
    default: boolean;
}
/**
 * Singleton class that represents the package directories defined in sfdx-project.json
 * as well as the "active" package directory during deployment/retrieval of source.
 * Provides the ability to parse source files for their package data, get the default
 * package, and other package directory utilities.
 */
export declare class PackageInfoCache {
    private static instance;
    packageConfigs: PackageConfig[];
    packageNames: string[];
    packagePaths: string[];
    defaultPackage: PackageConfig;
    private activePackage;
    private constructor();
    private static create;
    private init;
    static getInstance(): PackageInfoCache;
    private buildPackageList;
    getPackageNameFromSourcePath(sourcePath: string): Nullable<string>;
    /**
     * Returns the absolute path of the package directory ending with the path separator.
     * E.g., /Users/jsmith/projects/ebikes-lwc/force-app/
     *
     * @param packageName Name of the package directory.  E.g., 'force-app'
     */
    getPackagePath(packageName: string): Nullable<string>;
    getActivePackage(): Nullable<PackageConfig>;
    setActivePackage(pkgName: Nullable<string>): void;
    hasMultiplePackages(): boolean;
    getDefaultPackage(): PackageConfig;
}
export {};
